@@ -1,36 +1,45 @@
 package OptArgs2::Pager;
 use strict;
 use warnings;
+use OptArgs2::Mo;
 use Carp ();
 use Exporter::Tidy other => [qw/page start_pager stop_pager/];
 use File::Which;
 use IO::Handle;
-use OptArgs2::Pager_CI {
-
-    # User provided arguments
-    auto     => { default => 1, },
-    encoding => { default => ':utf8', },
-    pager    => { default => \&_build_pager, },
-
-    # Attributes
-    fh => {
-        init_arg => undef,
-        is       => 'rw',
-        default  => sub { IO::Handle->new },
-    },
-    orig_fh => {
-        init_arg => undef,
-        default  => sub { select },
-    },
-    pid => {
-        init_arg => undef,
-        is       => 'rw',
-        init_arg => undef,
-    },
-};
 
 our @CARP_NOT = (__PACKAGE__);
 
+# User provided arguments
+
+has auto => (
+    is      => 'ro',
+    default => 1,
+);
+
+has encoding => (
+    is      => 'ro',
+    default => ':utf8',
+);
+
+has pager => (
+    is      => 'ro',
+    default => \&_build_pager,
+);
+
+# Attributes
+
+has fh => (
+    is      => 'rw',
+    default => sub { IO::Handle->new },
+);
+
+has orig_fh => (
+    is      => 'ro',
+    default => sub { select },
+);
+
+has pid => ( is => 'rw' );
+
 sub _build_pager {
     my $self = shift;
 
@@ -55,23 +64,17 @@ sub _build_pager {
 
 sub BUILD {
     my $self = shift;
-    $self->open;
-    select $self->fh if $self->auto;
+    $self->open if $self->auto;
 }
 
 sub open {
     my $self = shift;
-
     return $self->fh if $self->fh->opened;
-
-    if ( not -t $self->orig_fh ) {
-        $self->fh( $self->orig_fh );
-        return;
-    }
+    return unless -t $self->orig_fh;
 
     my $pager = $self->pager || return;
 
-    local $ENV{LESS} = $ENV{LESS} // '-FSXeR';
+    local $ENV{LESS} = $ENV{LESS} // '-FXeR';
     local $ENV{MORE} = $ENV{MORE} // '-FXer' unless $^O eq 'MSWin32';
 
     $self->pid( CORE::open( $self->fh, '|-', $pager ) )
@@ -81,6 +84,8 @@ sub open {
       or Carp::cluck "Could not set bindmode: $!";
 
     $self->fh->autoflush(1);
+
+    select $self->fh;
 }
 
 sub close {
@@ -88,7 +93,7 @@ sub close {
     return unless $self->fh && $self->fh->opened;
 
     select $self->orig_fh;
-    $self->fh->close if $self->fh ne $self->orig_fh;
+    $self->fh->close;
 }
 
 sub DESTROY {
@@ -102,24 +107,20 @@ my $pager;
 sub start_pager {
     $pager //= __PACKAGE__->new(@_);
     $pager->open;
-    select $pager->fh;
 }
 
 sub stop_pager {
-    $pager // return;
-    $pager->close;
-    select( $pager->orig_fh );
+    $pager->close if $pager;
 }
 
 sub page {
-    my $text  = shift;
-    my $close = not $pager;
+    my $text = shift;
 
-    $pager //= __PACKAGE__->new( @_, auto => 0 );
+    my $close = not $pager;
+    $pager //= __PACKAGE__->new(@_);
     $pager->open;
-    my $ok = $pager->fh->printflush($text);
+    $pager->fh->printflush($text);
     $pager->close if $close;
-    $ok;
 }
 
 1;
@@ -134,7 +135,7 @@ OptArgs2::Pager - pipe output to a system (text) pager
 
 =head1 VERSION
 
-2.0.0 (2022-10-05)
+2.0.0_1 (2022-02-03)
 
 =head1 SYNOPSIS
 
@@ -173,8 +174,7 @@ is selected again.
 An all-in-one function to start a pager (using the optional C<%ARGS>
 passed directly to C<new()> below), send it a C<$string>, and close it.
 If a pager is already running when this is called (due to a previous
-C<start_pager()>) it will reused and left open. Returns the response
-from the underlying printflush().
+C<start_pager()>) it will reused and left open.
 
 =head2 start_pager(%ARGS)
 
@@ -194,9 +194,8 @@ The C<new()> constuctor takes the following arguments.
 
 =item C<< auto => 1 >>
 
-By default the pager is selected as the default filehandle when the
-object is created. Set C<auto> to a false value to inhibit this
-behaviour.
+By default the pager is opened when the object is created. Set C<auto>
+to a false value to inhibit this behaviour.
 
 =item C<< encoding => ':utf8' >>
 
@@ -251,13 +250,6 @@ pager is already running.
 
 =back
 
-=head1 ENVIRONMENT
-
-Already mentioned above is the check for C<$PAGER> when choosing which
-pager to run. Additionally, OptArgs2 temporarily sets C<$LESS> to
-C<-FSXeR> and C<$MORE> to C<-FXer> if they are unset at the time the
-pager is opened.
-
 =head1 SEE ALSO
 
 L<IO::Pager> - does something similar by mucking directly with STDOUT
